//
// C++ Interface: CDefault
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CDEFAULTDLG_H
#define CDEFAULTDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "CQcakeDlg.hpp"
#include "ui_default4.h"

class CDefaultDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CDefaultDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CDefaultDlg();

 
private slots:
 
protected:
    Ui::DefaultDlg ui;    

private:
    QWidget *myParent;
};
#endif
